
/*
 * File......: Str2Arr.prg
 * Author....: Jovan Bulajic
 * E-mail....: bulaja@sezampro.yu
 * Version...: 1.0
 * Date......: written sometime in '95 :)
 *             released to public on Apr 7th '97
 *
 * This is an original work by Jovan Bulajic and is placed in the
 * public domain.
 *
 */


/*  $DOC$
 *  $FUNCNAME$
 *     Str2Array()
 *  $ONELINER$
 *     Converts string to array of words
 *  $SYNTAX$
 *     Str2Array( <cString>, [<cSeparators>] ) -> aWords
 *  $ARGUMENTS$
 *     <cString>     is a string to process
 *     <cSeparators> is a optional string of possible delimiters used
 *                   to separate words, default separators are " ,."
 *                   (space, comma and point).
 *  $RETURNS$
 *     Return array of separated strings (words).
 *  $DESCRIPTION$
 *     Str2Array() function (in my programs I'm also calling it
 *     Str2Words()) analyze passed string and returns back array
 *     of all separate words, based on possible delimiters. This
 *     can be quite handy whenever you prefer to deal with array
 *     elements than with whole string - see the following examples.
 *     Keep on mind Clipper's limitation of 4096 elements in array
 *     so be careful with converting large string (e.g. whole text
 *     files)
 *
 *  $EXAMPLES$
 *
 *      // transforms active color string to
 *      // array of separate colors
 *      aColors := Str2Array ( SetColor() )
 *
 *      // separate last and first name, can be also used
 *      // on same way to separate parts of ZIP code.
 *      cName := "Doe, John"
 *      aName := Str2Array ( cName )
 *      ? "Firstname=", aName[2]
 *      ? "Lastname =", aName[1]
 *
 *      // convert to separate lines from text file with
 *      // lines delimited with LF (e.g. file from some
 *      // mainframe which common have such structure)
 *      cString := Memoread ("FILE.LST")
 *      aLines  := Str2Array (cString, Chr(10)) // use LF as delimiter
 *
 *      // separate words from string and then
 *      // re-create the string, but delimited
 *      // with CR-LF
 *      aWords := Str2Array (cString)
 *      cString := ""
 *      AEval (aWords, { |cWord| cString += cWord + Chr(13)+Chr(10) })
 *
 *  $END$
 */


**** ---------------------------------------- ****
function Str2Array (cString, cSeparators)

    local aWords, cWord, cChar, i

    if Empty(cSeparators)
        cSeparators := " .,"
    endif

    aWords := {}
    cWord  := ""

    for i := 1 TO Len(cString)
        cChar := SubStr(cString, i, 1)
        if cChar $ cSeparators
            if ! Empty(cWord)
                AAdd (aWords, cWord)
                cWord := ""
            endif
        else
            cWord += cChar
        endif
    next

    if ! Empty(cWord)
        AAdd(aWords, cWord)
    endif

return (aWords)

